#' summary.phenologyout prints the information from a result object.
#' @title Print the summary information from a ouput object.
#' @author Marc Girondot
#' @return None\cr
#' @param object An output generated by plot_phenology
#' @param ... Not used
#' @description The function summary.phenologyout displays the output from a plot.
#' @examples
#' library(phenology)
#' # Read a file with data
#' \dontrun{
#' Gratiot<-read.delim("http://max2.ese.u-psud.fr/epc/conservation/BI/Complete.txt", header=FALSE)
#' }
#' data(Gratiot)
#' # Generate a formatted list nammed data_Gratiot 
#' data_Gratiot<-add_phenology(Gratiot, name="Complete", 
#' 		reference=as.Date("2001-01-01"), format="%d/%m/%Y")
#' # Generate initial points for the optimisation
#' parg<-par_init(data_Gratiot, parametersfixed=NULL)
#' # Run the optimisation
#' \dontrun{
#' result_Gratiot<-fit_phenology(data=data_Gratiot, 
#' 		parametersfit=parg, parametersfixed=NULL, trace=1)
#' }
#' data(result_Gratiot)
#' # Plot the phenology and get some stats
#' output<-plot(result_Gratiot)
#' # Show the output
#' summary(output)
#' @method summary phenologyout
#' @export


summary.phenologyout <- function(object, ...) {

	cat(paste("Number of timeseries: ", length(object), "\n", sep=""))
	for (i in 1:length(object)) {
		cat(paste(names(object)[i], "\n", sep=""))
	}

}
